# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/plasma/01_mhd_waves.ipynb.

# %% auto 0
__all__ = ['VpVg_fs']

# %% ../../nbs/plasma/01_mhd_waves.ipynb 1
import numpy as np
from numpy import cos, sin, sqrt


def VpVg_fs(cs, ca, theta=None):
    """Calculates the phase velocities and group velocities for fast and slow waves."""
    if theta is None:
        theta = np.arange(0, 360, 1) * np.pi / 180

    cos_angle = cos(theta)
    sin_angle = sin(theta)

    cm = sqrt(cs**2 + ca**2)

    cn4 = cm**4 - 4 * cs**2 * ca**2 * cos_angle**2
    cn2 = sqrt(cn4)

    tmp2 = cm**2 - cn2

    Cp_slow = sqrt(0.5 * (tmp2))
    Cp_fast = sqrt(0.5 * (cm**2 + cn2))

    Cg_slow_perp = (
        sin_angle * Cp_slow * (1 - cs**2 * ca**2 / Cp_slow**2 / cn2 * cos_angle**2)
    )
    Cg_slow_para = (
        cos_angle * Cp_slow * (1 + cs**2 * ca**2 / Cp_slow**2 / cn2 * sin_angle**2)
    )

    Cg_fast_perp = (
        sin_angle * Cp_fast * (1 + cs**2 * ca**2 / Cp_fast**2 / cn2 * cos_angle**2)
    )
    Cg_fast_para = (
        cos_angle * Cp_fast * (1 - cs**2 * ca**2 / Cp_fast**2 / cn2 * sin_angle**2)
    )

    return {
        "Vps": Cp_slow,
        "Vpf": Cp_fast,
        "Vgs_perp": Cg_slow_perp,
        "Vgs_para": Cg_slow_para,
        "Vgf_perp": Cg_fast_perp,
        "Vgf_para": Cg_fast_para,
    }
